#!/usr/bin/env python
#-*- coding:utf-8 -*-
#===============================================================================
#  Copyright (C) 2010 Schaefer & Tobies SuC GmbH.
#  Author: Markus Grimm <mgr@schaefer-tobies.de>
#
#  This file is part of Pyontapi.
#
#  Pyontapi is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyontapi is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Pyontapi.  If not, see <http://www.gnu.org/licenses/>.
#
#===============================================================================

""" pyontapi setup script """

import distutils.core
import os
import shutil
import stat
import sys
import tempfile

from distutils.command.install import install as StockInstallCommand

class InstallCommand(StockInstallCommand):

    def run(self):
        StockInstallCommand.run(self)
        
        # set chmod 777 to schtob/pyontapi/api folder.
        mode = stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR | \
               stat.S_IRGRP | stat.S_IWGRP | stat.S_IXGRP | \
               stat.S_IROTH | stat.S_IWOTH | stat.S_IXOTH
        path = os.path.join(self.install_libbase, 'schtob', 'pyontapi', 'api')
        
        print "Setting write permission to", path
        os.chmod(path, mode)
        
        path = os.path.join(self.install_libbase, 'schtob', 'pyontapi', 
                            'local_settings.py')
        os.chmod(path, mode)
        
def main():
    """ run distutils.setup """
    
    # Exclude local_settings.py from being added to package/installation
    local_settings_py = os.path.join('src', 'schtob', 'pyontapi', 
                                     'local_settings.py'
    )
    temp_file_path = None
    if os.path.exists(local_settings_py):
        temp_file_path = os.path.join(tempfile.gettempdir(), 
                                      'pyontapi_local_settings.py')
        shutil.move(local_settings_py, temp_file_path)
    
    handle = file(local_settings_py,'w')
    handle.write('')
    handle.close()
    
    sys.path.append('src')
    from schtob.pyontapi import VERSION
    
    distutils.core.setup(
        name='Pyontapi',
        version=VERSION,
        description='Python NetApp ONTAPI Implementation',
        long_description=('Pyontapi is a Python implementation '
                          'for the NetApp ONTAP API. It automatically '
                          'generates Python code according to the ONTAPI '
                          'version of your NetApp filer using the system-api-* '
                          'API commands.'),
        author='Markus Grimm',
        author_email='mgr@schaefer-tobies.de',
        url='http://pyontapi.schaefer-tobies.de',
        license='LGPL', # TODO: license
        platforms=['POSIX', 'Windows'],
        packages=['schtob', 'schtob.pyontapi', 'schtob.pyontapi.api', 
                  'schtob.pyontapi.generator', 'schtob.pyontapi.bin'],
        package_dir = {'': 'src'},
        scripts=[os.path.join('src', 'schtob', 'pyontapi', 'bin', 
                              'pyontapi_list_commands.py'),
                 os.path.join('src', 'schtob', 'pyontapi', 'bin',
                              'pyontapi_setup.py')],
        cmdclass={'install':InstallCommand},
    )
    
    # restore local_settings.py
    if temp_file_path:
        shutil.move(temp_file_path, local_settings_py)

if __name__ == '__main__':
    main()